rnalysis.enrichment.RankedSet.single\_set\_go\_enrichment
=========================================================

.. currentmodule:: rnalysis.enrichment

.. automethod:: RankedSet.single_set_go_enrichment